Description Fields Methods See Also Examples
ModelMPWR represents an estimated MPWR model.
paramA ParamMPWR object. It contains the estimated values of the parameters.
statA StatMPWR object. It contains all the statistics associated to the MPWR model.
plot(what = c("regressors", "segmentation"), ...)Plot method.
whatThe type of graph requested:
"regressors" = Polynomial regression components
(field regressors of class StatMPWR).
"segmentation" = Estimated signal
(field mean_function of class StatMPWR).
...Other graphics parameters.
By default, all the graphs mentioned above are produced.
summary(digits = getOption("digits"))Summary method.
digitsThe number of significant digits to use when printing.
ParamMPWR, StatMPWR
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | data(toydataset)
x <- toydataset$x
Y <- as.matrix(toydataset[,c("y1", "y2", "y3")])
mpwr <- fitMPWR(X = x, Y = Y, K = 5, p = 1)
# mpwr is a ModelMPWR object. It contains some methods such as 'summary' and 'plot'
mpwr$summary()
mpwr$plot()
# mpwr has also two fields, stat and param which are reference classes as well
# Value of the objective function:
mpwr$stat$objective
# Parameters of the polynomial regressions:
mpwr$param$beta
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.