Description Fields Methods See Also
StatMPWR contains all the statistics associated to a MPWR model.
z_ikLogical matrix of dimension (m, K) giving the class vector.
klasColumn matrix of the labels issued from z_ik. Its elements are
klas(i) = k, k = 1,…,K.
mean_functionApproximation of the time series given the estimated
parameters. mean_function is a matrix of size (m, d).
regressorsArray of size (m, d, K) giving the values of the estimated polynomial regression components.
objectiveNumeric. Value of the objective function.
computeStats(paramMPWR)Method used at the end of the dynamic programming algorithm to compute
statistics based on parameters provided by paramMPWR.
ParamMPWR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.